@@ -8,6 +8,7 @@
 #' @param PI A numeric value specifying the performance indicator to plot
 #' @param byMP Logical. Facet by MP? Defaults to FALSE, where all MPs are shown on the same plot
 #' @param byOM Logical. Facet by OM?  Defaults to FALSE where values are calculated as mean across OMs
+#' @param OMs Integers representing the OMs to include in the plot. Defaults to all.
 #' @param includeHist Logical. Include the historical period in the projections?
 #' @param ncol Numeric. Number of columns if faceting by MP or OM
 #' @param col_line Color for the median line (historical)
@@ -38,7 +39,7 @@
 #' @param inc_y_label Include the label for the y-axis?
 #' @param sims Optional. Numeric values indicating the simulations to include. Defaults
 #' to all.
-#' @param lang Optional. Language (if supported in Slick Object). Either 'en', 'es', 'fr'
+#' @param lang Optional. Language (if supported in Slick Object). Either 'en', 'es', 'fr', or 'pt'
 #'
 #' @seealso [Timeseries()], [Timeseries-class()]
 #' @return A `ggplot2` object
@@ -49,6 +50,7 @@ plotTimeseries <- function(slick,
                            PI=1,
                            byMP=FALSE,
                            byOM=FALSE,
+                           OMs=NA,
                            includeHist=TRUE,
                            ncol=4,
                            col_line='darkgray',
@@ -82,6 +84,12 @@ plotTimeseries <- function(slick,
   if (!methods::is(slick, 'Slick'))
     cli::cli_abort('`slick` must be an object of class `Slick`')
 
+  slick <- Update(slick)
+
+  if (!all(is.na(OMs))) {
+    slick <- FilterSlick(slick, OMs=OMs, plot='Timeseries')
+  }
+
   MeanMed <- match.arg(MeanMed)
 
   timeseries <- Timeseries(slick)
@@ -134,9 +142,10 @@ plotTimeseries <- function(slick,
   p <- ggplot2::ggplot() +
     ggplot2::theme_bw()
 
-  if (includeHist) {
+  if (includeHist & max(hist.yr.ind) >1) {
     proj.yr.ind <- (hist.yr.ind):length(times)
     proj.yrs <- times[proj.yr.ind]
+
     # Historical Period
     if (byOM) {
       hist.values <- values[,oms,1, PI,1:hist.yr.ind, drop=FALSE]
@@ -269,8 +278,8 @@ plotTimeseries <- function(slick,
   } else {
     proj.values <- values[sims,oms,, PI,proj.yr.ind, drop=FALSE]
     # mean over OMs
-    mean.mps <- apply(proj.values, c(3,5), mean, na.rm=TRUE) # mean over simulations
-    med.mps <- apply(proj.values, c(3,5), median, na.rm=TRUE) # median over simulations
+    mean.mps <- apply(proj.values, c(3,5), mean, na.rm=TRUE) # mean over simulations and OMs
+    med.mps <- apply(proj.values, c(3,5), median, na.rm=TRUE) # median over simulations and OMs
 
     meddf <- data.frame(x=rep(proj.yrs, each=nMP),
                         MP=MP_lab,
@@ -420,7 +429,7 @@ plotTimeseries <- function(slick,
     }
     if (!is.null(limit)) {
       lim <- limit[PI]
-      if (!is.na(targ)) {
+      if (!is.na(lim)) {
         x_loc <- times[1]
         if (!includeHist) {
           x_loc <- time_now+1
